@@ -27,25 +27,28 @@
 #include <KMessageBox>
 #include <KRecentDirs>
 
-#include <dht/dht.h>
-#include <dht/dhtbase.h>
-#include <torrent/globals.h>
-#include <groups/group.h>
-#include <groups/groupmanager.h>
-#include <util/stringcompletionmodel.h>
-#include <interfaces/functions.h>
 #include "core.h"
 #include "gui.h"
 #include "torrentcreatordlg.h"
+#include <dht/dht.h>
+#include <dht/dhtbase.h>
+#include <groups/group.h>
+#include <groups/groupmanager.h>
+#include <interfaces/functions.h>
+#include <torrent/globals.h>
 #include <util/error.h>
 #include <util/log.h>
-
+#include <util/stringcompletionmodel.h>
 
 using namespace bt;
 
 namespace kt
 {
-TorrentCreatorDlg::TorrentCreatorDlg(Core* core, GUI* gui, QWidget* parent) : QDialog(parent), core(core), gui(gui), mktor(nullptr)
+TorrentCreatorDlg::TorrentCreatorDlg(Core *core, GUI *gui, QWidget *parent)
+    : QDialog(parent)
+    , core(core)
+    , gui(gui)
+    , mktor(nullptr)
 {
     setAttribute(Qt::WA_DeleteOnClose);
     tracker_completion = webseeds_completion = nodes_completion = nullptr;
@@ -80,7 +83,6 @@ TorrentCreatorDlg::TorrentCreatorDlg(Core* core, GUI* gui, QWidget* parent) : QD
     m_move_up->setEnabled(false);
     m_move_down->setEnabled(false);
 
-
     // dht box
     connect(m_add_node, &QPushButton::clicked, this, &TorrentCreatorDlg::addNodePressed);
     connect(m_node, &QLineEdit::returnPressed, this, &TorrentCreatorDlg::addNodePressed);
@@ -94,7 +96,7 @@ TorrentCreatorDlg::TorrentCreatorDlg(Core* core, GUI* gui, QWidget* parent) : QD
     const QMap<QString, int> n = bt::Globals::instance().getDHT().getClosestGoodNodes(10);
 
     for (QMap<QString, int>::const_iterator it = n.cbegin(); it != n.cend(); ++it) {
-        QTreeWidgetItem* twi = new QTreeWidgetItem(m_node_list);
+        QTreeWidgetItem *twi = new QTreeWidgetItem(m_node_list);
         twi->setText(0, it.key());
         twi->setText(1, QString::number(it.value()));
         m_node_list->addTopLevelItem(twi);
@@ -124,15 +126,15 @@ TorrentCreatorDlg::~TorrentCreatorDlg()
 
 void TorrentCreatorDlg::loadGroups()
 {
-    GroupManager* gman = core->getGroupManager();
+    GroupManager *gman = core->getGroupManager();
     GroupManager::Itr it = gman->begin();
 
     QStringList grps;
 
-    //First default group
+    // First default group
     grps << i18n("All Torrents");
 
-    //now custom ones
+    // now custom ones
     while (it != gman->end()) {
         if (!it->second->isStandardGroup())
             grps << it->first;
@@ -142,7 +144,6 @@ void TorrentCreatorDlg::loadGroups()
     m_group->addItems(grps);
 }
 
-
 void TorrentCreatorDlg::loadCompleterData()
 {
     QString file = kt::DataDir() + QStringLiteral("torrent_creator_known_trackers");
@@ -177,8 +178,8 @@ void TorrentCreatorDlg::removeTrackerPressed()
 
 void TorrentCreatorDlg::moveUpPressed()
 {
-    const QList<QListWidgetItem*> sel = m_tracker_list->selectedItems();
-    for (QListWidgetItem* s : sel) {
+    const QList<QListWidgetItem *> sel = m_tracker_list->selectedItems();
+    for (QListWidgetItem *s : sel) {
         int r = m_tracker_list->row(s);
         if (r > 0) {
             m_tracker_list->insertItem(r - 1, m_tracker_list->takeItem(r));
@@ -189,8 +190,8 @@ void TorrentCreatorDlg::moveUpPressed()
 
 void TorrentCreatorDlg::moveDownPressed()
 {
-    const QList<QListWidgetItem*> sel = m_tracker_list->selectedItems();
-    for (QListWidgetItem* s : sel) {
+    const QList<QListWidgetItem *> sel = m_tracker_list->selectedItems();
+    for (QListWidgetItem *s : sel) {
         int r = m_tracker_list->row(s);
         if (r + 1 < m_tracker_list->count()) {
             m_tracker_list->insertItem(r + 1, m_tracker_list->takeItem(r));
@@ -202,7 +203,7 @@ void TorrentCreatorDlg::moveDownPressed()
 void TorrentCreatorDlg::addNodePressed()
 {
     if (m_node->text().length() > 0) {
-        QTreeWidgetItem* twi = new QTreeWidgetItem(m_node_list);
+        QTreeWidgetItem *twi = new QTreeWidgetItem(m_node_list);
         nodes_completion->addString(m_node->text());
         twi->setText(0, m_node->text());
         twi->setText(1, QString::number(m_port->value()));
@@ -223,7 +224,7 @@ void TorrentCreatorDlg::dhtToggled(bool on)
     m_tracker_tab->setEnabled(!on);
 }
 
-void TorrentCreatorDlg::nodeTextChanged(const QString& str)
+void TorrentCreatorDlg::nodeTextChanged(const QString &str)
 {
     m_add_node->setEnabled(str.length() > 0);
 }
@@ -233,7 +234,7 @@ void TorrentCreatorDlg::nodeSelectionChanged()
     m_remove_node->setEnabled(m_node_list->selectedItems().count() > 0);
 }
 
-void TorrentCreatorDlg::trackerTextChanged(const QString& str)
+void TorrentCreatorDlg::trackerTextChanged(const QString &str)
 {
     m_add_tracker->setEnabled(str.length() > 0);
 }
@@ -269,7 +270,7 @@ void TorrentCreatorDlg::removeWebSeedPressed()
     qDeleteAll(m_webseed_list->selectedItems());
 }
 
-void TorrentCreatorDlg::webSeedTextChanged(const QString& str)
+void TorrentCreatorDlg::webSeedTextChanged(const QString &str)
 {
     m_add_webseed->setEnabled(str.length() > 0);
 }
@@ -287,8 +288,9 @@ void TorrentCreatorDlg::accept()
     }
 
     if (m_tracker_list->count() == 0 && !m_dht->isChecked()) {
-        QString msg = i18n("You have not added a tracker, "
-                           "are you sure you want to create this torrent?");
+        QString msg = i18n(
+            "You have not added a tracker, "
+            "are you sure you want to create this torrent?");
         if (KMessageBox::warningYesNo(gui, msg) == KMessageBox::No)
             return;
     }
@@ -299,9 +301,7 @@ void TorrentCreatorDlg::accept()
     }
 
     QUrl url = m_url->url();
-    Uint32 chunk_size_table[] = {
-        32, 64, 128, 256, 512, 1024, 2048, 4096, 8192, 16384
-    };
+    Uint32 chunk_size_table[] = {32, 64, 128, 256, 512, 1024, 2048, 4096, 8192, 16384};
 
     int chunk_size = chunk_size_table[m_chunk_size->currentIndex()];
     QString name = url.toLocalFile();
@@ -311,32 +311,31 @@ void TorrentCreatorDlg::accept()
 
     if (m_dht->isChecked()) {
         for (int i = 0; i < m_node_list->topLevelItemCount(); ++i) {
-            QTreeWidgetItem* item = m_node_list->topLevelItem(i);
-            trackers.append(item->text(0) + QLatin1Char(',') +  item->text(1));
+            QTreeWidgetItem *item = m_node_list->topLevelItem(i);
+            trackers.append(item->text(0) + QLatin1Char(',') + item->text(1));
         }
     } else {
         for (int i = 0; i < m_tracker_list->count(); ++i) {
-            QListWidgetItem* item = m_tracker_list->item(i);
+            QListWidgetItem *item = m_tracker_list->item(i);
             trackers.append(item->text());
         }
     }
 
     QList<QUrl> webseeds;
     for (int i = 0; i < m_webseed_list->count(); ++i) {
-        QListWidgetItem* item = m_webseed_list->item(i);
+        QListWidgetItem *item = m_webseed_list->item(i);
         webseeds.append(QUrl(item->text()));
     }
 
     try {
-        mktor = new bt::TorrentCreator(url.toLocalFile(), trackers, webseeds, chunk_size, name,
-                                       m_comments->text(), m_private->isChecked(), m_dht->isChecked());
+        mktor = new bt::TorrentCreator(url.toLocalFile(), trackers, webseeds, chunk_size, name, m_comments->text(), m_private->isChecked(), m_dht->isChecked());
 
         connect(mktor, &bt::TorrentCreator::finished, this, &TorrentCreatorDlg::hashCalculationDone, Qt::QueuedConnection);
         mktor->start();
         setProgressBarEnabled(true);
         update_timer.start(1000);
         m_progress->setMaximum(mktor->getNumChunks());
-    } catch (bt::Error& err) {
+    } catch (bt::Error &err) {
         delete mktor;
         mktor = 0;
         Out(SYS_GEN | LOG_IMPORTANT) << "Error: " << err.toString() << endl;
@@ -350,9 +349,10 @@ void TorrentCreatorDlg::hashCalculationDone()
     update_timer.stop();
 
     QString recentDirClass;
-    QString s = QFileDialog::getSaveFileName(this, i18n("Choose a file to save the torrent"),
-                KFileWidget::getStartUrl(QUrl(QStringLiteral("kfiledialog:///openTorrent")), recentDirClass).toLocalFile(),
-                kt::TorrentFileFilter(false));
+    QString s = QFileDialog::getSaveFileName(this,
+                                             i18n("Choose a file to save the torrent"),
+                                             KFileWidget::getStartUrl(QUrl(QStringLiteral("kfiledialog:///openTorrent")), recentDirClass).toLocalFile(),
+                                             kt::TorrentFileFilter(false));
 
     if (s.isEmpty()) {
         QDialog::reject();
@@ -366,12 +366,12 @@ void TorrentCreatorDlg::hashCalculationDone()
         s += QLatin1String(".torrent");
 
     mktor->saveTorrent(s);
-    bt::TorrentInterface* tc = core->createTorrent(mktor, m_start_seeding->isChecked());
+    bt::TorrentInterface *tc = core->createTorrent(mktor, m_start_seeding->isChecked());
     if (m_group->currentIndex() > 0 && tc) {
         QString groupName = m_group->currentText();
 
-        GroupManager* gman = core->getGroupManager();
-        Group* group = gman->find(groupName);
+        GroupManager *gman = core->getGroupManager();
+        Group *group = gman->find(groupName);
         if (group) {
             group->addTorrent(tc, true);
             gman->saveGroups();
@@ -416,5 +416,4 @@ void TorrentCreatorDlg::selectDirectory()
     m_url->setMode(KFile::ExistingOnly | KFile::LocalOnly | KFile::Directory);
 }
 
-
 }
