@@ -22,11 +22,11 @@
 #ifndef TRAYICON_H
 #define TRAYICON_H
 
-#include <QMenu>
 #include <KStatusNotifierItem>
+#include <QMenu>
 
-#include <util/constants.h>
 #include <interfaces/torrentinterface.h>
+#include <util/constants.h>
 
 using namespace bt;
 
@@ -34,13 +34,9 @@ class QString;
 
 namespace kt
 {
-
 struct CurrentStats;
-
 class Core;
-
 class SetMaxRate;
-
 class GUI;
 
 struct TrayStats {
@@ -53,17 +49,17 @@ struct TrayStats {
 /**
  * @author Joris Guisson
  * @author Ivan Vasic
-*/
+ */
 
 class TrayIcon : public QObject
 {
     Q_OBJECT
 public:
-    TrayIcon(Core* tc, GUI* parent);
+    TrayIcon(Core *tc, GUI *parent);
     ~TrayIcon() override;
 
     /// Update stats for system tray icon
-    void updateStats(const CurrentStats& stats);
+    void updateStats(const CurrentStats &stats);
 
     /// Update the max rate menus
     void updateMaxRateMenus();
@@ -75,70 +71,70 @@ public:
     void hide();
 
     /// Get the co
-    QMenu* contextMenu();
+    QMenu *contextMenu();
 
 private:
-    void showPassivePopup(const QString& msg, const QString& titile);
+    void showPassivePopup(const QString &msg, const QString &titile);
 
 private Q_SLOTS:
     /**
-             * Show a passive popup, that a torrent has been silently added.
-             * @param tc The torrent
-             */
-    void torrentSilentlyOpened(bt::TorrentInterface* tc);
+     * Show a passive popup, that a torrent has been silently added.
+     * @param tc The torrent
+     */
+    void torrentSilentlyOpened(bt::TorrentInterface *tc);
 
     /**
      * Show a passive popup, that the torrent has stopped downloading.
      * @param tc The torrent
      */
-    void finished(bt::TorrentInterface* tc);
+    void finished(bt::TorrentInterface *tc);
 
     /**
      * Show a passive popup that a torrent has reached it's max share ratio.
      * @param tc The torrent
      */
-    void maxShareRatioReached(bt::TorrentInterface* tc);
+    void maxShareRatioReached(bt::TorrentInterface *tc);
 
     /**
      * Show a passive popup that a torrent has reached it's max seed time
      * @param tc The torrent
      */
-    void maxSeedTimeReached(bt::TorrentInterface* tc);
+    void maxSeedTimeReached(bt::TorrentInterface *tc);
 
     /**
      * Show a passive popup when a torrent has been stopped by an error.
      * @param tc The torrent
      * @param msg Error message
      */
-    void torrentStoppedByError(bt::TorrentInterface* tc, QString msg);
+    void torrentStoppedByError(bt::TorrentInterface *tc, QString msg);
 
     /**
      * Corrupted data has been found.
      * @param tc The torrent
      */
-    void corruptedData(bt::TorrentInterface* tc);
+    void corruptedData(bt::TorrentInterface *tc);
 
     /**
      * User tried to enqueue a torrent that has reached max share ratio or max seed time
      * Show passive popup message.
      */
-    void queuingNotPossible(bt::TorrentInterface* tc);
+    void queuingNotPossible(bt::TorrentInterface *tc);
 
     /**
      * We failed to start a torrent
      * @param tc The torrent
      * @param reason The reason it failed
      */
-    void canNotStart(bt::TorrentInterface* tc, bt::TorrentStartResponse reason);
+    void canNotStart(bt::TorrentInterface *tc, bt::TorrentStartResponse reason);
 
-    ///Shows passive popup message
-    void lowDiskSpace(bt::TorrentInterface* tc, bool stopped);
+    /// Shows passive popup message
+    void lowDiskSpace(bt::TorrentInterface *tc, bool stopped);
 
     /**
      * A torrent could not be loaded silently.
      * @param msg Message to show
      */
-    void cannotLoadTorrentSilently(const QString& msg);
+    void cannotLoadTorrentSilently(const QString &msg);
 
     /**
         The QM changes suspended state.
@@ -148,21 +144,21 @@ private Q_SLOTS:
     /**
         Show a warning message
     */
-    void dhtNotEnabled(const QString& msg);
+    void dhtNotEnabled(const QString &msg);
 
 private Q_SLOTS:
-    void secondaryActivate(const QPoint& pos);
+    void secondaryActivate(const QPoint &pos);
 
 private:
-    Core* core;
-    GUI* mwnd;
+    Core *core;
+    GUI *mwnd;
     int previousDownloadHeight;
     int previousUploadHeight;
-    SetMaxRate* max_upload_rate;
-    SetMaxRate* max_download_rate;
-    KStatusNotifierItem* status_notifier_item;
+    SetMaxRate *max_upload_rate;
+    SetMaxRate *max_download_rate;
+    KStatusNotifierItem *status_notifier_item;
     bool queue_suspended;
-    QMenu* menu;
+    QMenu *menu;
 };
 
 class SetMaxRate : public QMenu
@@ -170,9 +166,10 @@ class SetMaxRate : public QMenu
     Q_OBJECT
 public:
     enum Type {
-        UPLOAD, DOWNLOAD
+        UPLOAD,
+        DOWNLOAD,
     };
-    SetMaxRate(Core* tc, Type t, QWidget* parent);
+    SetMaxRate(Core *tc, Type t, QWidget *parent);
     ~SetMaxRate() override;
 
 public Q_SLOTS:
@@ -182,12 +179,12 @@ private:
     void makeMenu();
 
 private Q_SLOTS:
-    void onTriggered(QAction* act);
+    void onTriggered(QAction *act);
 
 private:
-    Core* m_core;
+    Core *m_core;
     Type type;
-    QAction* unlimited;
+    QAction *unlimited;
 };
 }
 
