@@ -26,32 +26,31 @@
 
 namespace kt
 {
-
-typedef bool (*IsMemberFunction)(TorrentInterface* tor);
+typedef bool (*IsMemberFunction)(TorrentInterface *tor);
 
 /**
     Group which calls a function pointer to test for membership
 */
-template <IsMemberFunction fn>
-class FunctionGroup : public Group
+template<IsMemberFunction fn> class FunctionGroup : public Group
 {
 public:
-    FunctionGroup(const QString& name, const QString& icon, int flags, const QString& path)
+    FunctionGroup(const QString &name, const QString &icon, int flags, const QString &path)
         : Group(name, flags, path)
     {
         setIconByName(icon);
     }
 
-    ~FunctionGroup() override {}
+    ~FunctionGroup() override
+    {
+    }
 
-    bool isMember(TorrentInterface* tor) override
+    bool isMember(TorrentInterface *tor) override
     {
         if (!tor)
             return false;
         else
             return fn(tor);
     }
-
 };
 
 }
