@@ -18,8 +18,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#include <torrent/queuemanager.h>
 #include "group.h"
+#include <torrent/queuemanager.h>
 
 namespace kt
 {
@@ -30,47 +30,51 @@ Group::Policy::Policy()
     only_apply_on_new_torrents = false;
 }
 
-Group::Group(const QString& name, int flags, const QString& path) :
-    name(name),
-    flags(flags),
-    path(path),
-    running(0),
-    total(0)
-{}
-
+Group::Group(const QString &name, int flags, const QString &path)
+    : name(name)
+    , flags(flags)
+    , path(path)
+    , running(0)
+    , total(0)
+{
+}
 
 Group::~Group()
-{}
-
-void Group::save(bt::BEncoder*)
 {
 }
 
-void Group::load(bt::BDictNode*)
+void Group::save(bt::BEncoder *)
 {
 }
 
-void Group::setIconByName(const QString& in)
+void Group::load(bt::BDictNode *)
+{
+}
+
+void Group::setIconByName(const QString &in)
 {
     icon_name = in;
     // KF5 icon = SmallIcon(in);
 }
 
-void Group::rename(const QString& nn)
+void Group::rename(const QString &nn)
 {
     name = nn;
 }
 
-void Group::torrentRemoved(TorrentInterface*)
-{}
+void Group::torrentRemoved(TorrentInterface *)
+{
+}
 
-void Group::removeTorrent(TorrentInterface*)
-{}
+void Group::removeTorrent(TorrentInterface *)
+{
+}
 
-void Group::addTorrent(TorrentInterface*, bool)
-{}
+void Group::addTorrent(TorrentInterface *, bool)
+{
+}
 
-void Group::setGroupPolicy(const Policy& p)
+void Group::setGroupPolicy(const Policy &p)
 {
     policy = p;
     policyChanged();
@@ -80,10 +84,10 @@ void Group::policyChanged()
 {
 }
 
-void Group::updateCount(QueueManager* qman)
+void Group::updateCount(QueueManager *qman)
 {
     total = running = 0;
-    for (bt::TorrentInterface * tor : qAsConst(*qman)) {
+    for (bt::TorrentInterface *tor : qAsConst(*qman)) {
         if (isMember(tor)) {
             total++;
             if (tor->getStats().running)
