@@ -26,35 +26,33 @@
 #include <QDialogButtonBox>
 #include <QLineEdit>
 #include <QRegularExpression>
-#include <QVBoxLayout>
 #include <QUrl>
+#include <QVBoxLayout>
 
 #include <KLocalizedString>
 
 namespace kt
 {
-
-AddTrackersDialog::AddTrackersDialog(QWidget* parent, const QStringList& tracker_hints): QDialog(parent)
+AddTrackersDialog::AddTrackersDialog(QWidget *parent, const QStringList &tracker_hints)
+    : QDialog(parent)
 {
     setWindowTitle(i18n("Add Trackers"));
     trackers = new KEditListWidget(this);
     trackers->setButtons(KEditListWidget::Add | KEditListWidget::Remove);
 
     // If we find any urls on the clipboard, add them
-    QClipboard* clipboard = QApplication::clipboard();
+    QClipboard *clipboard = QApplication::clipboard();
     const QStringList urlStrings = clipboard->text().split(QRegularExpression(QLatin1String("\\s")));
-    for (const QString& s : urlStrings) {
+    for (const QString &s : urlStrings) {
         QUrl url(s);
-        if (url.isValid() && (url.scheme() == QLatin1String("http")
-                              || url.scheme() == QLatin1String("https")
-                              || url.scheme() == QLatin1String("udp"))) {
+        if (url.isValid() && (url.scheme() == QLatin1String("http") || url.scheme() == QLatin1String("https") || url.scheme() == QLatin1String("udp"))) {
             trackers->insertItem(s);
         }
     }
 
     trackers->lineEdit()->setCompleter(new QCompleter(tracker_hints));
 
-    QDialogButtonBox* box = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    QDialogButtonBox *box = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     connect(box, &QDialogButtonBox::accepted, this, &AddTrackersDialog::accept);
     connect(box, &QDialogButtonBox::rejected, this, &AddTrackersDialog::reject);
 
@@ -72,5 +70,4 @@ QStringList AddTrackersDialog::trackerList() const
     return trackers->items();
 }
 
-
 }
