@@ -22,19 +22,15 @@
 
 namespace kt
 {
-
-ProxyHelper::ProxyHelper(DBusSettings* settings): m_settings(settings)
+ProxyHelper::ProxyHelper(DBusSettings *settings)
+    : m_settings(settings)
 {
-
 }
 
-bool ProxyHelper::ApplyProxy(KIO::MetaData& metadata) const
+bool ProxyHelper::ApplyProxy(KIO::MetaData &metadata) const
 {
-    if (!SearchPluginSettings::openInExternal() &&
-        SearchPluginSettings::useProxySettings() &&
-        m_settings) {
-        if (!m_settings->useKDEProxySettings() &&
-            !m_settings->httpProxy().trimmed().isEmpty()) {
+    if (!SearchPluginSettings::openInExternal() && SearchPluginSettings::useProxySettings() && m_settings) {
+        if (!m_settings->useKDEProxySettings() && !m_settings->httpProxy().trimmed().isEmpty()) {
             QString p = QStringLiteral("%1:%2").arg(m_settings->httpProxy()).arg(m_settings->httpProxyPort());
             if (!p.startsWith(QLatin1String("http://")))
                 p = QStringLiteral("http://") + p;
